/******************************************************************************
   File:
      COUNTER.C

   Purpose:
      Structs and functions related to keeping track of the timers

   $Revision: 1.4 $
   $Header: F:\devel\pilot\clock/RCS/counter.c,v 1.4 1997/09/07 19:11:25 eshayne Exp $
   $Log: counter.c,v $
 * Revision 1.4  1997/09/07  19:11:25  eshayne
 * added GNU Public License to source files
 *
 * Revision 1.3  1997/09/01  19:09:39  eshayne
 * added popup/beep when time is out for one player
 *
 * Revision 1.2  1997/09/01  16:08:30  eshayne
 * added Fischer time
 *
 * Revision 1.1  1997/09/01  14:43:04  eshayne
 * Initial revision
 *

    Chess Timer
    Copyright (C) 1997  Ethan Shayne

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

******************************************************************************/

#include <Common.h>
#include <System/SysAll.h>
#include <UI/UIAll.h>

#include <counter.h>


Boolean DecrementCounter(struct TimeCounter* pCounter)
{
  if (--(pCounter->miSeconds) < 0) {
    pCounter->miSeconds = 59;
    (pCounter->miMinutes)--;
  }

  return ((pCounter->miSeconds > 0) || (pCounter->miMinutes > 0));
}


void IncrementCounter(struct TimeCounter* pCounter,
		      const unsigned long ulAddition)
{
  pCounter->miSeconds += ulAddition;
  while (pCounter->miSeconds > 59) {
    (pCounter->miMinutes)++;
    pCounter->miSeconds -= 60;
  }
}


/* checks if it's time yet to decrement the supplied counter
   (based on the supplied "next tick" time) - if so, decrements
   it and redraws that timer */
/* returns false if the timer updated has reached 0 */
Boolean UpdateTimer(unsigned long* pulNextTick,
		    struct TimeCounter* pCounter,
		    FieldPtr pMinutesField,
		    FieldPtr pSecondsField)
{
  Boolean boolReturnVal = true;

  if (TimGetTicks() >= *pulNextTick) {
    *pulNextTick += sysTicksPerSecond;
    boolReturnVal = DecrementCounter(pCounter);

    DrawTimer(pCounter, pMinutesField, pSecondsField);
  }

  return boolReturnVal;
}


void DrawTimer(struct TimeCounter* pCounter,
	       FieldPtr pMinutesField,
	       FieldPtr pSecondsField)
{
  static char pszMinutesBuffer[3];
  static char pszSecondsBuffer[3];

  char* pszTempMinutes = pszMinutesBuffer;
  char* pszTempSeconds = pszSecondsBuffer;

  if ((*pCounter).miMinutes < 10) {
    pszMinutesBuffer[0] = '0';
    pszTempMinutes = pszMinutesBuffer + 1;
  }
  
  if ((*pCounter).miSeconds < 10) {
    pszSecondsBuffer[0] = '0';
    pszTempSeconds = pszSecondsBuffer + 1;
  }
  
  StrIToA(pszTempMinutes, (*pCounter).miMinutes);
  StrIToA(pszTempSeconds, (*pCounter).miSeconds);
  
  FldSetTextPtr(pMinutesField, pszMinutesBuffer);
  FldRecalculateField(pMinutesField, true);
  FldDrawField(pMinutesField);
  FldSetTextPtr(pSecondsField, pszSecondsBuffer);
  FldRecalculateField(pSecondsField, true);
  FldDrawField(pSecondsField);
}



